
.. lcapy documentation master file, created by
   sphinx-quickstart on Mon Feb 17 17:08:01 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Lcapy's documentation!
=================================

Lcapy is a Python package for linear circuit analysis.  It uses
SymPy (symbolic Python) for symbolic analysis.  As well as circuit analysis, Lcapy can semi-automate the drawing of high-quality schematics from a netlist, including diodes, transistors, and other non-linear components..

.. image:: examples/schematics/lpf1-buffer-loaded2.png
   :width: 11cm

Contents:
=========

.. toctree::
   :maxdepth: 3

   overview.rst
   install.rst
   expressions.rst
   discretetime.rst                         
   circuits.rst
   networks.rst
   netlists.rst
   schematics.rst
   tutorials.rst           
   latex.rst
   config.rst                                                      
   problems.rst                          
   internals.rst            
   modules.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

